pub struct ZoneComparison {
pub zone: String,
pub kind: ComparisonKind,
pub differences: Vec<Difference>,
pub byte_identical: bool,
}Expand description
Outcome of comparing our output against reference zic for a single zone.
Fields
zone: Stringkind: ComparisonKinddifferences: Vec<Difference>Differences found; empty means the two agree under this comparison kind.
byte_identical: boolWhether the two files were byte-identical (a stricter, informational signal).
Implementations